Learn R Programming

morestopwords (version 0.2.0)

del.stopwords: Removes stop words for a string the language of which is known

Description

Removes stop words for a string the language of which is known

Usage

del.stopwords(str, lang)

Value

A character vector corresponding to the string str without stopwords for the language lang

Arguments

str

The string which to delete the stop words from

lang

Either an ISO 639-2/3 or a language name from which to derive a ISO 639-2 code. For language names performs string matching.