powered by
Removes stop words for a string the language of which is known
del.stopwords(str, lang)
A character vector corresponding to the string str without stopwords for the language lang
str
lang
The string which to delete the stop words from
Either an ISO 639-2/3 or a language name from which to derive a ISO 639-2 code. For language names performs string matching.